@@ -204,7 +204,11 @@
 	  A theme subclass may override the -imageClass method to change the
 	  class used to load each image from the bundle ... thus allowing
 	  customisation of not just the images but also of the image
-	  behavior in the (very rare) cases where this is desirable.
+	  behavior in the (very rare) cases where this is desirable.<br />
+          Finally, a theme may provide application specific images which are
+          loaded <em>in preference to</em> named images from the application's
+          own bundle.  These images are simply stored in a subdirectory whose
+          name is the same as the application's bundleIdentifier.
 	</desc>
       </deflist>
     </section>
@@ -235,8 +239,8 @@
 #if	OS_API_VERSION(GS_API_NONE,GS_API_NONE)
 @class NSArray;
 @class NSBundle;
+@class NSBrowserCell;
 @class NSDictionary;
-
 @class NSButton;
 @class NSColor;
 @class NSColorList;
@@ -1053,8 +1057,10 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  *
  * <p>The title color is mapped to the theme state as described below:</p>
  * <deflist>
- * <item>GSThemeSelectedState</item><desc>[NSColor+selectedMenuItemTextColor]</desc>
- * <item>GSThemeDisabledState</item><desc>[NSColor+controlTextColor] or 
+ * <term>GSThemeSelectedState</term>
+ * <desc>[NSColor+selectedMenuItemTextColor]</desc>
+ * <term>GSThemeDisabledState</term>
+ * <desc>[NSColor+controlTextColor] or 
  * [NSColor+disabledControlTextColor]</desc>
  * </deflist>
  */
@@ -1076,7 +1082,8 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  */
 - (NSColor *) menuSeparatorColor;
 /**
- * <p>Returns the left and right inset used to draw a separator line in a menu.</p>
+ * <p>Returns the left and right inset used to draw a separator line in a
+ * menu.</p>
  *
  * <p>By default, returns 3.0.</p>
  *
@@ -1109,7 +1116,7 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  * -isSeparatorItem</p>
  *
  * <p>You can provide an image tile named <em>GSMenuSeparatorItem</em> to 
- * draw the separator.</br>
+ * draw the separator.<br />
  * Can be overridden in subclasses to customize the drawing.</p>
  *
  * <p>See also -menuSeparatorColor and -menuSeparatorInset</p>
@@ -1163,6 +1170,14 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
 
 - (float) resizebarHeight;
 
+- (float) titlebarButtonSize;
+
+- (float) titlebarPaddingRight;
+
+- (float) titlebarPaddingTop;
+
+- (float) titlebarPaddingLeft;
+
 - (void) drawWindowBorder: (NSRect)rect
                 withFrame: (NSRect)frame 
              forStyleMask: (unsigned int)styleMask
@@ -1457,5 +1472,60 @@ withRepeatedImage: (NSImage*)image
 - (Class) pageLayoutClass;
 @end
 
+@interface GSTheme (NSWindow)
+/**
+ * This method returns the standard window button for the
+ * given mask for the current theme.
+ */ 
+- (NSButton *) standardWindowButton: (NSWindowButton)button
+		       forStyleMask: (NSUInteger) mask;
+				  
+/** 
+ * This method does any additional setup after the default 
+ * cell is set.
+ */
+- (void) didSetDefaultButtonCell: (NSButtonCell *)aCell;
+@end
+					 
+@interface GSTheme (NSBrowserCell)
+/** 
+ * Draw editor in cell
+ */
+- (void) drawEditorForCell: (NSCell *)cell
+		 withFrame: (NSRect)cellFrame
+	       	    inView: (NSView *)view;
+
+/** 
+ * Draw attributed text in cell
+ */
+- (void) drawInCell: (NSCell *)cell
+     attributedText: (NSAttributedString *)stringValue
+	    inFrame: (NSRect)cellFrame;
+
+/** 
+ * Draw the interior of the browser cell
+ */
+- (void) drawBrowserInteriorWithFrame: (NSRect)cellFrame 
+			     withCell: (NSBrowserCell *)cell
+			       inView: (NSView *)controlView
+			    withImage: (NSImage *)theImage
+		       alternateImage: (NSImage *)alternateImage
+			isHighlighted: (BOOL)isHighlighted
+				state: (int)state
+			       isLeaf: (BOOL)isLeaf;
+
+/** 
+ * This method returns the branch image
+ */
+- (NSImage *) branchImage;
+
+/** 
+ * This method returns the highlighted version of 
+ * the branch image
+ */
+- (NSImage *) highlightedBranchImage;
+@end
+
+
 #endif /* OS_API_VERSION */
 #endif /* _GNUstep_H_GSTheme */
